from scipy import stats
from sklearn.linear_model import LinearRegression
import matplotlib.pyplot as plt
import numpy as np
import math

#HYPOTHESIS TESTING:
def HypothesisTesting(Ttest, Pvalue):
    Ttest, Pvalue = stats.ttest_ind(Ttest, Pvalue)
    print(f"SADUSTATISTICS' HYPOTHESIS TESTING RESULT: Ttest -> {Ttest}, and p-value -> {Pvalue}")


#LINEAR REQRESSION:
def LinearRegressionModel(ArrayA, ArrayB, DesiredValue):
    model = LinearRegression()
    model.fit(ArrayA, ArrayB)
    print(f"SADUSTATISTICS' LINEAR REGRESSION ANALYSIS RESULT: {model.predict([[DesiredValue]])}")



def ConfidenceInterval(mean, stdev, n, confidence_level= 1.82):
    conf = confidence_level * (stdev / (math.sqrt(n)))
    print(f"SADUSTATISTICS' CONFIDENCE INTERVAL RESULT: {mean - conf, mean + conf}")


def HistPlot(n, m, stdev):
    print(f"SADUSTATISTICS' HISTOGRAM PLOT RESULT: {np.random.normal(m, stdev, n)}")


def MatplotlibHistogram(n, mean, stdev):
    data = HISTPLOT(n, mean, stdev)
    plt.hist(data, color='red', label='histogramo')
    plt.title("HISTOGRAMPLOT")
    plt.xlabel("POINTS")
    plt.ylabel('VALUES')
    plt.grid(True)
    plt.legend()
    plt.show()



def DOT(a, b):
    print(f"SADUSTATISTICS' INNER(DOT) PRODUCT RESULT: {sum(x * y for x,y in zip(a, b))}")



from scipy import stats
import matplotlib.pyplot as plt
import numpy as np
import math
#MEAN:
def MEAN(data):
    print(f"SADUSTATISTICS' MEAN RESULT: {sum(data.values()) / len(data)}")

def MODE(data):
    frequency = {}
    for score in data.values():
        if score in frequency:
            frequency[score] += 1
        else:
            frequency[score] = 1

    max_freq = max(frequency.values())
    mode = [score for score, freq in frequency.items() if freq == max_freq]
    print(f"SADUSTATISTICS' MODE RESULT: {mode}")


def MEDIAN(data):
    sorted_data = sorted(data.values())
    n = len(sorted_data)
    mid = n // 2
    print(f"SADUSTATISTICS' MEDIAN RESULT: {[sorted_data[mid] if n % 2 != 0 else (sorted_data[mid - 1] + sorted_data[mid]) / 2]}")



from scipy import stats
import matplotlib.pyplot as plt
import numpy as np
import math
def RANGE(data):
    range = max(data.values()) - min(data.values())
    print(f"SADUSTATISTICS' RANGE RESULT: {range}")


def VARIANCE(data, mean):
    print(f"SADUSTATISTICS' VARIANCE RESULT: {sum((x - mean) ** 2 for x in data.values()) / len(data.items())}")


def StandardDeviation(data, mean):
    print(f"SADUSTATISTICS' STANDARD DEVIATION RESULT: {math.sqrt(sum((x - mean) ** 2 for x in data.values()) / len(data.items()))}")


def InterQuartile(data):
    sorted_data = sorted(data.values())
    q1 = sorted_data[1 * len(sorted_data) // 4]
    q3 = sorted_data[3 * len(sorted_data) // 4]
    print(f"SADUSTATISTICS' RESULT: {q3- q1}")
